@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.40.2.1 2002/07/10 23:15:14 mmclouglin Exp $
+ $Id: battstat_applet.c,v 1.46 2002/12/09 00:44:31 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,8 @@
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
+#include <egg-screen-help.h>
+
 /*#include <status-docklet.h>*/
 
 #include "battstat.h"
@@ -696,6 +698,8 @@ battstat_error_dialog (PanelApplet *applet,
 			GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_OK,
 			msg);
+	gtk_window_set_screen (GTK_WINDOW (dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (applet)));
 
 	gtk_dialog_run (GTK_DIALOG(dialog));
 	gtk_widget_destroy (dialog);
@@ -734,18 +738,23 @@ help_cb (BonoboUIComponent *uic,
 	 ProgressData      *battstat,
 	 const char        *verb)
 {
-  /* FIXME
-   GnomeHelpMenuEntry help_entry = {
-      "battstat_applet", "index.html"
-   };
-   gnome_help_display (NULL, &help_entry);
-  */
+    GError *error = NULL;
+
+    egg_screen_help_display (
+		gtk_widget_get_screen (battstat->applet),
+		"battstat", NULL, &error);
+
+    if (error) { /* FIXME: the user needs to see this */
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
 }
 
 void
 helppref_cb (PanelApplet *applet, gpointer data)
 {
-  /* FIXME
+  /* FIXME: use (egg|gnome)_screen_help_display
        GnomeHelpMenuEntry help_entry = {
       "battstat_applet", "index.html#BATTSTAT_PREFS"
    };
@@ -849,6 +858,8 @@ about_cb (BonoboUIComponent *uic,
    	gdk_pixbuf_unref (pixbuf);
 
    gtk_window_set_wmclass (GTK_WINDOW (about_box), "battery charge monitor", "Batter Charge Monitor");
+   gtk_window_set_screen (GTK_WINDOW (about_box),
+			  gtk_widget_get_screen (battstat->applet));
    gtk_widget_show (about_box);
 }
 
@@ -1463,7 +1474,8 @@ battstat_applet_fill (PanelApplet *applet)
   battstat = g_new0 (ProgressData, 1);
   
   battstat->applet = GTK_WIDGET (applet);
-  
+  gtk_widget_realize (battstat->applet);
+
   battstat->hbox1 = gtk_hbox_new (FALSE, 1);
   gtk_widget_show(battstat->hbox1);
 
@@ -1485,9 +1497,9 @@ battstat_applet_fill (PanelApplet *applet)
 
   pixmap_timeout(battstat);
   change_orient (applet, battstat->orienttype, battstat );
-#if 1
+
   battstat->pixtimer = gtk_timeout_add (1000, pixmap_timeout, battstat);
-#endif  
+
   gtk_container_add (GTK_CONTAINER (battstat->applet), battstat->hbox1);
 
   panel_applet_setup_menu_from_file (PANEL_APPLET (battstat->applet), 
@@ -1517,7 +1529,7 @@ battstat_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_BattstatApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "Battstat",
+                             "battstat",
                              "0",
                              battstat_applet_factory,
                              NULL)
